@@ -3,4 +3,4 @@ from .excel import ExcelReader, ExcelWriter
 from .datafile import DataWriter, DataReader, ReadMode
 from .builder import open_reader, open_writer, list2csv, dict2csv, objects2csv, list2excel, \
     dict2excel, objects2excel, csv2list, csv2dict, csv2objects, excel2list, \
-    excel2dict, excel2objects
+    excel2dict, excel2objects, load, load_objs, load_dicts, load_lists, save, save_objs, save_dicts, save_lists
